@@ -16,7 +16,8 @@ DEFAULTS = {
     'homeloc': False,
     'ipv6': False,
     'threshold': 5,
-    'sens': 2
+    'sens': 2,
+    'mute':False
 }
 
 
@@ -52,6 +53,7 @@ def agent_check(
         public=DEFAULTS['public'],
         threshold=DEFAULTS['threshold'],
         sens=DEFAULTS['sens'],
+        mute=DEFAULTS['mute'],
         dep="",
         notifications="",
         oldresultfail=False,
@@ -116,6 +118,7 @@ def audio_check(
         homeloc=DEFAULTS['homeloc'],
         threshold=DEFAULTS['threshold'],
         sens=DEFAULTS['sens'],
+        mute=DEFAULTS['mute'],
         dep="",
         notifications="",
         **kwargs
@@ -146,7 +149,7 @@ def audio_check(
     :param enabled: If created check will be enabled or disabled
     :type public: bool
     :param public: If the results for the created check will be public or not
-    :type runlocations: str
+    :type runlocations: str or list
     :param runlocations: Which region to be originated from
     :type homeloc: str
     :param homeloc: Which probe in the region to originate the check from
@@ -182,6 +185,7 @@ def cluster_check(
         homeloc=DEFAULTS['homeloc'],
         threshold=DEFAULTS['threshold'],
         sens=DEFAULTS['sens'],
+        mute=DEFAULTS['mute'],
         dep="",
         notifications="",
         **kwargs
@@ -217,7 +221,7 @@ def cluster_check(
     :param enabled: If created check will be enabled or disabled
     :type public: bool
     :param public: If the results for the created check will be public or not
-    :type runlocations: str
+    :type runlocations: str or list
     :param runlocations: Which region to be originated from
     :type homeloc: str
     :param homeloc: Which probe in the region to originate the check from
@@ -263,6 +267,7 @@ def dns_check(
         homeloc=DEFAULTS['homeloc'],
         threshold=DEFAULTS['threshold'],
         sens=DEFAULTS['sens'],
+        mute=DEFAULTS['mute'],
         dep="",
         notifications="",
         verify=False,
@@ -298,7 +303,7 @@ def dns_check(
     :param enabled: If created check will be enabled or disabled
     :type public: bool
     :param public: If the results for the created check will be public or not
-    :type runlocations: str
+    :type runlocations: str or list
     :param runlocations: Which region to be originated from
     :type homeloc: str
     :param homeloc: Which probe in the region to originate the check from
@@ -348,6 +353,7 @@ def doh_dot_check(
         homeloc=DEFAULTS['homeloc'],
         threshold=DEFAULTS['threshold'],
         sens=DEFAULTS['sens'],
+        mute=DEFAULTS['mute'],
         dep="",
         notifications="",
         **kwargs
@@ -392,7 +398,7 @@ def doh_dot_check(
     :param enabled: If created check will be enabled or disabled
     :type public: bool
     :param public: If the results for the created check will be public or not
-    :type runlocations: str
+    :type runlocations: str or list
     :param runlocations: Which region to be originated from
     :type homeloc: str
     :param homeloc: Which probe in the region to originate the check from
@@ -434,6 +440,7 @@ def ftp_check(
         homeloc=DEFAULTS['homeloc'],
         threshold=DEFAULTS['threshold'],
         sens=DEFAULTS['sens'],
+        mute=DEFAULTS['mute'],
         dep="",
         notifications="",
         **kwargs
@@ -466,7 +473,7 @@ def ftp_check(
     :param enabled: If created check will be enabled or disabled
     :type public: bool
     :param public: If the results for the created check will be public or not
-    :type runlocations: str
+    :type runlocations: str or list
     :param runlocations: Which region to be originated from
     :type homeloc: str
     :param homeloc: Which probe in the region to originate the check from
@@ -505,6 +512,7 @@ def http_check(
         homeloc=DEFAULTS['homeloc'],
         threshold=DEFAULTS['threshold'],
         sens=DEFAULTS['sens'],
+        mute=DEFAULTS['mute'],
         dep="",
         notifications="",
         **kwargs
@@ -531,7 +539,7 @@ def http_check(
     :param enabled: If created check will be enabled or disabled
     :type public: bool
     :param public: If the results for the created check will be public or not
-    :type runlocations: str
+    :type runlocations: str or list
     :param runlocations: Which region to be originated from
     :type homeloc: str
     :param homeloc: Which probe in the region to originate the check from
@@ -578,6 +586,7 @@ def httpadv_check(
         homeloc=DEFAULTS['homeloc'],
         threshold=DEFAULTS['threshold'],
         sens=DEFAULTS['sens'],
+        mute=DEFAULTS['mute'],
         dep="",
         notifications="",
         **kwargs
@@ -626,7 +635,7 @@ def httpadv_check(
     :param enabled: If created check will be enabled or disabled
     :type public: bool
     :param public: If the results for the created check will be public or not
-    :type runlocations: str
+    :type runlocations: str or list
     :param runlocations: Which region to be originated from
     :type homeloc: str
     :param homeloc: Which probe in the region to originate the check from
@@ -667,6 +676,7 @@ def httpcontent_check(
         homeloc=DEFAULTS['homeloc'],
         threshold=DEFAULTS['threshold'],
         sens=DEFAULTS['sens'],
+        mute=DEFAULTS['mute'],
         dep="",
         notifications="",
         **kwargs
@@ -699,7 +709,7 @@ def httpcontent_check(
     :param enabled: If created check will be enabled or disabled
     :type public: bool
     :param public: If the results for the created check will be public or not
-    :type runlocations: str
+    :type runlocations: str or list
     :param runlocations: Which region to be originated from
     :type homeloc: str
     :param homeloc: Which probe in the region to originate the check from
@@ -738,6 +748,7 @@ def httpparse_check(
         homeloc=DEFAULTS['homeloc'],
         threshold=DEFAULTS['threshold'],
         sens=DEFAULTS['sens'],
+        mute=DEFAULTS['mute'],
         dep="",
         notifications="",
         **kwargs
@@ -788,7 +799,7 @@ def httpparse_check(
     :param enabled: If created check will be enabled or disabled
     :type public: bool
     :param public: If the results for the created check will be public or not
-    :type runlocations: str
+    :type runlocations: str or list
     :param runlocations: Which region to be originated from
     :type homeloc: str
     :param homeloc: Which probe in the region to originate the check from
@@ -834,6 +845,7 @@ def imap4_check(
         homeloc=DEFAULTS['homeloc'],
         threshold=DEFAULTS['threshold'],
         sens=DEFAULTS['sens'],
+        mute=DEFAULTS['mute'],
         dep="",
         notifications="",
         **kwargs
@@ -870,7 +882,7 @@ def imap4_check(
     :param enabled: If created check will be enabled or disabled
     :type public: bool
     :param public: If the results for the created check will be public or not
-    :type runlocations: str
+    :type runlocations: str or list
     :param runlocations: Which region to be originated from
     :type homeloc: str
     :param homeloc: Which probe in the region to originate the check from
@@ -894,12 +906,13 @@ def imap4_check(
     return _query_nodeping_api.post(url, check_variables)
 
 
-def mysql_check(
+def mtr_check(
         token,
         target,
         customerid=None,
         label="",
         autodiag=False,
+        ipv6=DEFAULTS['ipv6'],
         interval=DEFAULTS['interval'],
         enabled=DEFAULTS['enabled'],
         public=DEFAULTS['public'],
@@ -907,6 +920,81 @@ def mysql_check(
         homeloc=DEFAULTS['homeloc'],
         threshold=DEFAULTS['threshold'],
         sens=DEFAULTS['sens'],
+        mute=DEFAULTS['mute'],
+        dep="",
+        notifications="",
+        **kwargs
+):
+    """ Creates a NodePing MTR check
+
+    Expects a token and target variable. The rest are optional
+    and are configured to match the NodePing defaults as described
+    in the documentation.
+
+    :type token: string
+    :param token: NodePing account API token
+    :type target: string
+    :param target: URL to target host
+    :type customerid: string
+    :param customerid: Optional NodePing subaccount ID
+    :type label: string
+    :param label: Name of the check that will be created
+    :type autodiag: bool
+    :param autodiag: Enable/disable auto diagnostics for this check
+    :type ipv6: bool
+    :param ipv6: If the ping should be icmpv6
+    :type interval: int
+    :param interval: Interval in minutes to monitor target
+    :type enabled: bool
+    :param enabled: If created check will be enabled or disabled
+    :type public: bool
+    :param public: If the results for the created check will be public or not
+    :type runlocations: str or list
+    :param runlocations: Which region to be originated from
+    :type homeloc: str
+    :param homeloc: Which probe in the region to originate the check from
+    :type threshold: int
+    :param threshold: The max acceptable packet loss
+    :type sens: int
+    :param sens: Rechecks to help avoid unecessary notifications
+    :type dep: string
+    :param dep: ID of the check used for the notification dependency
+    :type notifications: list
+    :param notifications: list of objects containing contact ID, delay, and
+    scheduling for notifications
+    :return: Response from NodePing
+    :rtype: dict
+    """
+
+    check_variables = _package_variables(locals(), 'MTR')
+
+    url = _utils.create_url(token, API_URL, customerid)
+
+    return _query_nodeping_api.post(url, check_variables)
+
+
+def mysql_check(
+        token,
+        target,
+        customerid=None,
+        label="",
+        autodiag=False,
+        port=3306,
+        username=None,
+        password=None,
+        secure=False,
+        ipv6=False,
+        database=None,
+        query=None,
+        fields=None,
+        interval=DEFAULTS['interval'],
+        enabled=DEFAULTS['enabled'],
+        public=DEFAULTS['public'],
+        runlocations=DEFAULTS['runlocations'],
+        homeloc=DEFAULTS['homeloc'],
+        threshold=DEFAULTS['threshold'],
+        sens=DEFAULTS['sens'],
+        mute=DEFAULTS['mute'],
         dep="",
         notifications="",
         **kwargs
@@ -923,13 +1011,29 @@ def mysql_check(
     :param label: Name of the check that will be created
     :type autodiag: bool
     :param autodiag: Enable/disable auto diagnostics for this check
+    :type port: int
+    :param port: Port MySQL is listening on
+    :type username: str
+    :param username: Optional username to authenticate with
+    :type password: str
+    :param password: Optional password to authenticate with
+    :type secure: bool or string
+    :param bool: Use SSL/TLS. False or "ssl"
+    :type ipv6: bool
+    :param ipv6: If the ping should be icmpv6
+    :type database: str
+    :param database: Database name to query
+    :type query: str
+    :param query: Query to run on database
+    :type fields: dict
+    :param fields: Content in database to be matched
     :type interval: int
     :param interval: Interval in minutes to monitor target
     :type enabled: bool
     :param enabled: If created check will be enabled or disabled
     :type public: bool
     :param public: If the results for the created check will be public or not
-    :type runlocations: str
+    :type runlocations: str or list
     :param runlocations: Which region to be originated from
     :type homeloc: str
     :param homeloc: Which probe in the region to originate the check from
@@ -968,6 +1072,7 @@ def ntp_check(
         homeloc=DEFAULTS['homeloc'],
         threshold=DEFAULTS['threshold'],
         sens=DEFAULTS['sens'],
+        mute=DEFAULTS['mute'],
         dep="",
         notifications="",
         **kwargs
@@ -998,7 +1103,7 @@ def ntp_check(
     :param enabled: If created check will be enabled or disabled
     :type public: bool
     :param public: If the results for the created check will be public or not
-    :type runlocations: str
+    :type runlocations: str or list
     :param runlocations: Which region to be originated from
     :type homeloc: str
     :param homeloc: Which probe in the region to originate the check from
@@ -1036,6 +1141,7 @@ def ping_check(
         homeloc=DEFAULTS['homeloc'],
         threshold=DEFAULTS['threshold'],
         sens=DEFAULTS['sens'],
+        mute=DEFAULTS['mute'],
         dep="",
         notifications="",
         **kwargs
@@ -1064,7 +1170,7 @@ def ping_check(
     :param enabled: If created check will be enabled or disabled
     :type public: bool
     :param public: If the results for the created check will be public or not
-    :type runlocations: str
+    :type runlocations: str or list
     :param runlocations: Which region to be originated from
     :type homeloc: str
     :param homeloc: Which probe in the region to originate the check from
@@ -1108,6 +1214,7 @@ def pop3_check(
         homeloc=DEFAULTS['homeloc'],
         threshold=DEFAULTS['threshold'],
         sens=DEFAULTS['sens'],
+        mute=DEFAULTS['mute'],
         dep="",
         notifications="",
         **kwargs
@@ -1148,7 +1255,7 @@ def pop3_check(
     :param enabled: If created check will be enabled or disabled
     :type public: bool
     :param public: If the results for the created check will be public or not
-    :type runlocations: str
+    :type runlocations: str or list
     :param runlocations: Which region to be originated from
     :type homeloc: str
     :param homeloc: Which probe in the region to originate the check from
@@ -1187,6 +1294,7 @@ def port_check(
         homeloc=DEFAULTS['homeloc'],
         threshold=DEFAULTS['threshold'],
         sens=DEFAULTS['sens'],
+        mute=DEFAULTS['mute'],
         dep="",
         notifications="",
         **kwargs
@@ -1212,7 +1320,7 @@ def port_check(
     :param enabled: If created check will be enabled or disabled
     :type public: bool
     :param public: If the results for the created check will be public or not
-    :type runlocations: str
+    :type runlocations: str or list
     :param runlocations: Which region to be originated from
     :type homeloc: str
     :param homeloc: Which probe in the region to originate the check from
@@ -1236,6 +1344,143 @@ def port_check(
     return _query_nodeping_api.post(url, check_variables)
 
 
+def postgresql_check(
+        token,
+        target,
+        customerid=None,
+        label="",
+        autodiag=False,
+        query=None,
+        fields=None,
+        interval=DEFAULTS['interval'],
+        enabled=DEFAULTS['enabled'],
+        public=DEFAULTS['public'],
+        runlocations=DEFAULTS['runlocations'],
+        homeloc=DEFAULTS['homeloc'],
+        threshold=DEFAULTS['threshold'],
+        sens=DEFAULTS['sens'],
+        mute=DEFAULTS['mute'],
+        dep="",
+        notifications="",
+        **kwargs
+):
+    """ Creates a NodePing PGSQL check.
+
+    :type token: string
+    :param token: NodePing account API token
+    :type target: string
+    :param target: URL to target host
+    :type customerid: string
+    :param customerid: Optional NodePing subaccount ID
+    :type label: string
+    :param label: Name of the check that will be created
+    :type autodiag: bool
+    :param autodiag: Enable/disable auto diagnostics for this check
+    :type query: str
+    :param query: Query to run on database
+    :type fields: dict
+    :param fields: Content in database to be matched
+    :type interval: int
+    :param interval: Interval in minutes to monitor target
+    :type enabled: bool
+    :param enabled: If created check will be enabled or disabled
+    :type public: bool
+    :param public: If the results for the created check will be public or not
+    :type runlocations: str or list
+    :param runlocations: Which region to be originated from
+    :type homeloc: str
+    :param homeloc: Which probe in the region to originate the check from
+    :type threshold: int
+    :param threshold: Time in seconds for an acceptable response
+    :type sens: int
+    :param sens: Rechecks to help avoid unecessary notifications
+    :type dep: string
+    :param dep: ID of the check used for the notification dependency
+    :type notifications: list
+    :param notifications: list of objects containing contact ID, delay, and
+    scheduling for notifications
+    :return: Response from NodePing
+    :rtype: dict
+    """
+
+    check_variables = _package_variables(locals(), 'PGSQL')
+
+    url = _utils.create_url(token, API_URL, customerid)
+
+    return _query_nodeping_api.post(url, check_variables)
+
+
+def redis_check(
+        token,
+        target,
+        redistype,
+        hosts=[],
+        sentinelname=None,
+        customerid=None,
+        label="",
+        autodiag=False,
+        interval=DEFAULTS['interval'],
+        enabled=DEFAULTS['enabled'],
+        public=DEFAULTS['public'],
+        runlocations=DEFAULTS['runlocations'],
+        homeloc=DEFAULTS['homeloc'],
+        threshold=DEFAULTS['threshold'],
+        sens=DEFAULTS['sens'],
+        mute=DEFAULTS['mute'],
+        oldresultfail=False,
+        dep="",
+        notifications="",
+        **kwargs
+):
+    """ Creates a NodePing REDIS check
+
+    :type token: string
+    :param token: NodePing account API token
+    :type target: string
+    :param target: URL to target host
+    :type redistype: string
+    :param redistype: standalone, sentinel, cluster
+    :type hosts: list
+    :param hosts: For sentinel or cluster. The hostname, port, and password to connect
+    :sentinelname: The master/primary name for the sentinel to query
+    :type customerid: string
+    :param customerid: Optional NodePing subaccount ID
+    :type label: string
+    :param label: Name of the check that will be created
+    :type autodiag: bool
+    :param autodiag: Enable/disable auto diagnostics for this check
+    :type fields: dict
+    :param fields: Contents of each metric collected with min/max values
+    :type interval: int
+    :param interval: Interval in minutes to monitor target
+    :type enabled: bool
+    :param enabled: If created check will be enabled or disabled
+    :type public: bool
+    :param public: If the results for the created check will be public or not
+    :type runlocations: str or list
+    :param runlocations: Which region to be originated from
+    :type homeloc: str
+    :param homeloc: Which probe in the region to originate the check from
+    :type threshold: int
+    :param threshold: Time in seconds for an acceptable response
+    :type sens: int
+    :param sens: Rechecks to help avoid unecessary notifications
+    :type dep: string
+    :param dep: ID of the check used for the notification dependency
+    :type notifications: list
+    :param notifications: list of objects containing contact ID, delay, and
+    scheduling for notifications
+    :return: Response from NodePing
+    :rtype: dict
+    """
+
+    check_variables = _package_variables(locals(), 'REDIS')
+
+    url = _utils.create_url(token, API_URL, customerid)
+
+    return _query_nodeping_api.post(url, check_variables)
+
+
 def push_check(
         token,
         checktoken="reset",
@@ -1250,6 +1495,7 @@ def push_check(
         homeloc=DEFAULTS['homeloc'],
         threshold=DEFAULTS['threshold'],
         sens=DEFAULTS['sens'],
+        mute=DEFAULTS['mute'],
         oldresultfail=False,
         dep="",
         notifications="",
@@ -1300,7 +1546,7 @@ def push_check(
     :param enabled: If created check will be enabled or disabled
     :type public: bool
     :param public: If the results for the created check will be public or not
-    :type runlocations: str
+    :type runlocations: str or list
     :param runlocations: Which region to be originated from
     :type homeloc: str
     :param homeloc: Which probe in the region to originate the check from
@@ -1340,6 +1586,7 @@ def rbl_check(
         homeloc=DEFAULTS['homeloc'],
         threshold=DEFAULTS['threshold'],
         sens=DEFAULTS['sens'],
+        mute=DEFAULTS['mute'],
         dep="",
         notifications="",
         **kwargs
@@ -1369,7 +1616,7 @@ def rbl_check(
     :param enabled: If created check will be enabled or disabled
     :type public: bool
     :param public: If the results for the created check will be public or not
-    :type runlocations: str
+    :type runlocations: str or list
     :param runlocations: Which region to be originated from
     :type homeloc: str
     :param homeloc: Which probe in the region to originate the check from
@@ -1406,6 +1653,7 @@ def rdp_check(
         homeloc=DEFAULTS['homeloc'],
         threshold=DEFAULTS['threshold'],
         sens=DEFAULTS['sens'],
+        mute=DEFAULTS['mute'],
         dep="",
         notifications="",
         **kwargs
@@ -1428,7 +1676,7 @@ def rdp_check(
     :param enabled: If created check will be enabled or disabled
     :type public: bool
     :param public: If the results for the created check will be public or not
-    :type runlocations: str
+    :type runlocations: str or list
     :param runlocations: Which region to be originated from
     :type homeloc: str
     :param homeloc: Which probe in the region to originate the check from
@@ -1465,6 +1713,7 @@ def spec10dns_check(
         homeloc=DEFAULTS['homeloc'],
         threshold=DEFAULTS['threshold'],
         sens=DEFAULTS['sens'],
+        mute=DEFAULTS['mute'],
         dep="",
         notifications="",
         **kwargs
@@ -1500,7 +1749,7 @@ def spec10dns_check(
     :param enabled: If created check will be enabled or disabled
     :type public: bool
     :param public: If the results for the created check will be public or not
-    :type runlocations: str
+    :type runlocations: str or list
     :param runlocations: Which region to be originated from
     :type homeloc: str
     :param homeloc: Which probe in the region to originate the check from
@@ -1539,6 +1788,7 @@ def spec10rdds_check(
         homeloc=DEFAULTS['homeloc'],
         threshold=DEFAULTS['threshold'],
         sens=DEFAULTS['sens'],
+        mute=DEFAULTS['mute'],
         dep="",
         notifications="",
         **kwargs
@@ -1576,7 +1826,7 @@ def spec10rdds_check(
     :param enabled: If created check will be enabled or disabled
     :type public: bool
     :param public: If the results for the created check will be public or not
-    :type runlocations: str
+    :type runlocations: str or list
     :param runlocations: Which region to be originated from
     :type homeloc: str
     :param homeloc: Which probe in the region to originate the check from
@@ -1616,6 +1866,7 @@ def sip_check(
         homeloc=DEFAULTS['homeloc'],
         threshold=DEFAULTS['threshold'],
         sens=DEFAULTS['sens'],
+        mute=DEFAULTS['mute'],
         dep="",
         notifications="",
         **kwargs
@@ -1638,7 +1889,7 @@ def sip_check(
     :param enabled: If created check will be enabled or disabled
     :type public: bool
     :param public: If the results for the created check will be public or not
-    :type runlocations: str
+    :type runlocations: str or list
     :param runlocations: Which region to be originated from
     :type homeloc: str
     :param homeloc: Which probe in the region to originate the check from
@@ -1683,6 +1934,7 @@ def smtp_check(
         homeloc=DEFAULTS['homeloc'],
         threshold=DEFAULTS['threshold'],
         sens=DEFAULTS['sens'],
+        mute=DEFAULTS['mute'],
         dep="",
         notifications="",
         **kwargs
@@ -1720,7 +1972,7 @@ def smtp_check(
     :param enabled: If created check will be enabled or disabled
     :type public: bool
     :param public: If the results for the created check will be public or not
-    :type runlocations: str
+    :type runlocations: str or list
     :param runlocations: Which region to be originated from
     :type homeloc: str
     :param homeloc: Which probe in the region to originate the check from
@@ -1761,6 +2013,7 @@ def snmp_check(
         homeloc=DEFAULTS['homeloc'],
         threshold=DEFAULTS['threshold'],
         sens=DEFAULTS['sens'],
+        mute=DEFAULTS['mute'],
         dep="",
         notifications="",
         **kwargs
@@ -1811,7 +2064,7 @@ def snmp_check(
     :param enabled: If created check will be enabled or disabled
     :type public: bool
     :param public: If the results for the created check will be public or not
-    :type runlocations: str
+    :type runlocations: str or list
     :param runlocations: Which region to be originated from
     :type homeloc: str
     :param homeloc: Which probe in the region to originate the check from
@@ -1855,6 +2108,7 @@ def ssh_check(
         homeloc=DEFAULTS['homeloc'],
         threshold=DEFAULTS['threshold'],
         sens=DEFAULTS['sens'],
+        mute=DEFAULTS['mute'],
         dep="",
         notifications="",
         **kwargs
@@ -1885,7 +2139,7 @@ def ssh_check(
     :param enabled: If created check will be enabled or disabled
     :type public: bool
     :param public: If the results for the created check will be public or not
-    :type runlocations: str
+    :type runlocations: str or list
     :param runlocations: Which region to be originated from
     :type homeloc: str
     :param homeloc: Which probe in the region to originate the check from
@@ -1924,6 +2178,7 @@ def ssl_check(
         homeloc=DEFAULTS['homeloc'],
         threshold=DEFAULTS['threshold'],
         sens=DEFAULTS['sens'],
+        mute=DEFAULTS['mute'],
         dep="",
         notifications="",
         **kwargs
@@ -1950,7 +2205,7 @@ def ssl_check(
     :param enabled: If created check will be enabled or disabled
     :type public: bool
     :param public: If the results for the created check will be public or not
-    :type runlocations: str
+    :type runlocations: str or list
     :param runlocations: Which region to be originated from
     :type homeloc: str
     :param homeloc: Which probe in the region to originate the check from
@@ -1990,6 +2245,7 @@ def websocket_check(
         homeloc=DEFAULTS['homeloc'],
         threshold=DEFAULTS['threshold'],
         sens=DEFAULTS['sens'],
+        mute=DEFAULTS['mute'],
         dep="",
         notifications="",
         **kwargs
@@ -2018,7 +2274,7 @@ def websocket_check(
     :param enabled: If created check will be enabled or disabled
     :type public: bool
     :param public: If the results for the created check will be public or not
-    :type runlocations: str
+    :type runlocations: str or list
     :param runlocations: Which region to be originated from
     :type homeloc: str
     :param homeloc: Which probe in the region to originate the check from
@@ -2060,6 +2316,7 @@ def whois_check(
         homeloc=DEFAULTS['homeloc'],
         threshold=DEFAULTS['threshold'],
         sens=DEFAULTS['sens'],
+        mute=DEFAULTS['mute'],
         dep="",
         notifications="",
         **kwargs
@@ -2092,7 +2349,7 @@ def whois_check(
     :param enabled: If created check will be enabled or disabled
     :type public: bool
     :param public: If the results for the created check will be public or not
-    :type runlocations: str
+    :type runlocations: str or list
     :param runlocations: Which region to be originated from
     :type homeloc: str
     :param homeloc: Which probe in the region to originate the check from
